
# -----------------------------------------------------------------------------
# GiDCustomHelp --
#
# Html based help system. Show the help window.
#
# Arguments -- pairs of <option value>, where option could be:
#
#   -title : window title, defaults to "Help on <ProblemType name>"
#
#   -dir : path to help content. If -dir is missing it defaults to
#          "<ProblemType dir>/html". Multilingual content could be present, in
#          such case it is assumed that there is a directory for each language
#          provided. If the currente language is not found, language 'en'
#          (for english) is tried. Finally if 'en' is not found the value
#          provided to the option -dir is assumed as the base directory for the
#          help content.
#
#   -start : is a path relative to the value of -dir to an html link. For
#            instance:
#             -start html-version 
#             -start html-tutorials/tutorial_1
#
#   -report : boolean value indicating if the the window format is report. If
#             report is requested no tree is showed, only the content pane is
#             showed.
#
# Structure of the help contents--
#

#   Assuming we have chosen html as the base directory for the multilingual
#   help contents we can have the following structure:
#
#      html
#       \__ en - English content
#       
#       \__ es - Spanish content
#
#   Each content will provably have a directory structre to organize the
#   information. By default the help system build a tree resembling the
#   directory structre of the help content. In this sense there will be an
#   internal node for each subdirectory, finally the html documents will be
#   the terminal nodes of the tree.
#
#   We can also provide a help.conf configuration file in order to provide
#   more information about the estructure of the help. In a help file we can
#   specify a table of contents (TocPage), help subdirectories (HelpDirs)
#   and topic index (IndexPage).
#
# HelpDirs --
# 
#  With HelpDirs we can specify wich of the subdirectories will be internal
#  nodes of the help tree. Also we can specify label for the node and a link
#  to load when the noded is clicked. The link is relative the node. For
#  instance:
#
#      HelpDirs {html-version "GiD Help" "intro/intro.html"} \
#               {html-customization "GiD Customization"} \
#               {html-faq "Frequently Asked Questions"} \
#               {html-tutorials "GiD Tutorials" "tutorials_toc.html"} \
#               {html_whatsnew "Whats New"}
#
# TocPage --
#
#  TocPage define an html page as a page describing a table of contents of
#  the current node (current directory). We have considered two ways for
#  specifying a table of content:
#
#     1- <UL> <LI> ... </UL> (default)
#     2- <DT> <DL> ... </DT>
#
#  The first is the one generated by texinfo.
#
#  For instance:
#
#    TocPage gid_toc.html
#
#    TolcPage contents.ht DT
#
# IndexPage --
#
#  If we specify by IndexPage a topic index we can take advantage of the
#  search index. In indexPage we can provide a set of html index pages along
#  with the structure type of the index. The type of the index could be:
#
#    1- <DIR> <LI> ... </DIR> (default)
#    2- <UL> <LI> ... </UL> (only one level of <UL>)
#
#  The first is the one generated by texinfo.
#
#  For instance:
#
#    IndexPage html-version/gid_18.html html-faq/faq_11.html
#
#
# help.conf example, taken from info dir in gid instalation:
#
#    HelpDirs \
#      {html-version "GiD Help" "intro/intro.html"} \
#      {html-customization "GiD Customization"} \
#      {html-faq "Frequently Asked Questions"} \
#      {html-tutorials "GiD Tutorials" "tutorials_toc.html"} \
#      {html_whatsnew "Whats New"}
#
#      IndexPage html-version/gid_18.html html-faq/faq_11.html
# -----------------------------------------------------------------------------

proc GiDCustomHelp { args } {
  array set options {
    -start ""
    -report 0
  }
  set lan [GidUtils::GetCurrentLanguage]
  set options(-dir) [file join [GetDirectoryProblemType] html]
  if { [file exists $options(-dir)] && [file isdirectory $options(-dir)] } {
      set lan [GidUtils::GetCurrentLanguage]
      set dirhelp [file join $options(-dir) $lan]
      if { ![file exists $dirhelp] && $lan != "en" } {
	  set lan en
	  set dirhelp [file join [GetDirectoryProblemType] html $lan]
      }
      if { [file exists $dirhelp] && [file isdirectory $dirhelp] } {
	  set options(-title) $dirhelp
      }
  }
  set options(-title) [_ "Help on %s" [GiD_Info Project Problemtype]]
  array set options $args
  GiDHelpWindow -type CUSTOM -dir $options(-dir) -start $options(-start) \
      -report $options(-report) -title $options(-title)
}

proc GiDGetHelpLangDir { base_dir } {
  set lan [GidUtils::GetCurrentLanguage]
  set found 0
  foreach dl [list $lan en] {
    set lan_dir [file join $base_dir $dl]
    if {[file exists $lan_dir]} {
      set found 1
      break
    }
  }
  if {$found} {
    return $lan_dir
  }
  return $base_dir
}

proc GiDGetInfoDir { } {
  GiDGetHelpLangDir [file join $::GIDDEFAULT info] 
}

proc GiDHelpWindow { args } {
  array set options {
    -type "REFERENCE"
    -dir ""
    -start ""
    -report 0
    -toplevel ""
    -tab tree
  }
  set options(-title) [_ "Help"]
  array set options $args
  
  switch [string toupper $options(-type)] {
    REFERENCE {
      set options(-dir) [GiDGetInfoDir]
      set options(-title) [_ "GiD Reference"]
    }
    REPORT {
      set options(-title) [_ "Report"]
      set options(-report) 1
    }
    CUSTOM {
      set options(-toplevel) .ctmhelp
    }
  }
  
  if {$options(-dir) eq ""} {
    error [_ "Calling GiDHelpWindow: should provide a -dir option"] 
  }
  
  if {$options(-toplevel) eq ""} {
    GiDHelpViewer::Show $options(-dir) \
	-title $options(-title) \
	-try $options(-start) \
	-report $options(-report) \
	-tab $options(-tab)
    
  } else {
    GiDHelpViewer::Show $options(-dir) \
	-title $options(-title) \
	-try $options(-start) \
	-report $options(-report) \
	-base $options(-toplevel) \
	-tab $options(-tab)
  }
} 


proc GiDHelpWindow { args } {
  array set options {
    -type "REFERENCE"
    -dir ""
    -start ""
    -report 0
    -toplevel ""
    -tab tree
  }
  set options(-title) [_ "Help"]
  array set options $args
  
  switch [string toupper $options(-type)] {
    REFERENCE {
      set options(-dir) [GiDGetInfoDir]
      set options(-title) [_ "GiD Reference"]
    }
    REPORT {
      set options(-title) [_ "Report"]
      set options(-report) 1
    }
    CUSTOM {
      set options(-toplevel) .ctmhelp
    }
  }
  
  if {$options(-dir) eq ""} {
    error [_ "Calling GiDHelpWindow: should provide a -dir option"] 
  }

    set ghv GiDHelpViewer::Show
    if { $::tcl_platform(os) == "Darwin"} {
	set ghv GiDHelpViewer3::Show
    }

  if {$options(-toplevel) eq ""} {
    $ghv $options(-dir) \
	-title $options(-title) \
	-try $options(-start) \
	-report $options(-report) \
	-tab $options(-tab)
    
  } else {
    $ghv $options(-dir) \
	-title $options(-title) \
	-try $options(-start) \
	-report $options(-report) \
	-base $options(-toplevel) \
	-tab $options(-tab)
  }
} 

proc HelpWindow { help_type dir { intro_file "" } } {
    global var estat arbre finestra LastFile GIDDEFAULT
  
    GIDHELP_ini_var
    GIDHELP_setup $help_type
  
  
    set whlp $var(win)
    set top_whlp [winfo toplevel $whlp]
    set finestra $whlp.dreta.fondo.html
    
    
    
    if {$help_type == "REFERENCE"} {
	ini_ref
	wm geometry $top_whlp 800x550
	set var(path_manual) [file join [GiDGetInfoDir] html-version]
	set var(toc_file) gid_toc.html
	ShowContents
	if {$dir!=""} {generic_click $dir $whlp.dreta.fondo.html}
    }
    
    if {$help_type == "SEARCH"} {
	ini_ref
	
	set var(path_manual) [file join [GiDGetInfoDir] html-version]
	set var(toc_file) gid_toc.html       
	ShowSearch
    }
    
    if {$help_type == "CUSTOMIZATION"} {
	ini_cust
	
	set LastFile [file join $var(path_manual) ptype_toc.html]
	IndexLink [file join $var(path_manual) ptype_toc.html] $whlp.dreta.fondo.html  
	
    }
    
    if {$help_type == "FAQ"} {
	ini_faq
	
	set LastFile [file join $var(path_manual) faq_toc.html]
	IndexLink [file join $var(path_manual) faq_toc.html] $whlp.dreta.fondo.html    
    }
    
    if {$help_type == "CUSTOM_HELP"} {
	ini_other $dir
	
	set LastFile [file join $var(path_manual) index.html]
	IndexLink [file join $var(path_manual) index.html] $whlp.dreta.fondo.html    
    }
    
    if {$help_type == "CUSTOM_HELP_FILE" || $help_type == "TUTORIAL"} {
	
	ini_other_file $dir
	if {$help_type == "CUSTOM_HELP_FILE"} {wm geometry $top_whlp 679x580}
	if {$help_type == "TUTORIAL"} {wm geometry $top_whlp 600x500}
	
	set LastFile [file join $GIDDEFAULT $dir]
	IndexLink [file join $GIDDEFAULT $dir] $whlp.dreta.fondo.html    
    }
    
    if {$help_type == "CUSTOM_HELP_REFERENCE"} {
	ini_ref
	
	set var(path_manual) [file dirname $dir]
	set var(toc_file) [file tail $dir]
	set var(search_prefix) "_Toc"
	
	set var(path_search_file) [file join $var(path_manual) search_data.txt]
	set var(path_cindex) ""
	if { $intro_file == "" } {
	    set var(path_intro) $dir
	} else {
	    set var(path_intro) $intro_file
	}
	
	ShowContents
	if {$dir!="" && $intro_file=="" } {
	    generic_click $dir $whlp.dreta.fondo.html
	}
    }
    
}

proc directHelp {link} {
    global var estat
    #HelpWindow "REFERENCE" $link
    GiDHelpWindow -type REFERENCE -start [file join html-version $link]
}

proc ToolbarHelp {toolbar} {
    if {$toolbar == [_ "New GiD project"]} {
	return [list {gid14.html#FILES>New}]
    } elseif {$toolbar == [_ "Open GiD project"]} {
	return [list {gid15.html#FILES>Open}]
    } elseif {$toolbar == [_ "Save GiD project"]} {
	return  [list {gid16.html#FILES>Save}]
    } elseif {$toolbar == [_ "Previous view"] \
	    || $toolbar == [_ "Next view"] \
	    || $toolbar == [_ "List of views"]} {
	return  [list {gid27.html#VIEW>Zoom}]
    } elseif {$toolbar == [_ "Take a snapshot"]} {
	return [list {gid21.html#FILES>Print to file}]
    } elseif {$toolbar == [_ "Print current view"]} {
	return [list {gid23.html#FILES>Print}]
    } elseif {$toolbar == [_ "Toggle between pre and postprocess"]} {
	return [list {gid20.html#FILES>Preprocess/Postprocess}]
    } elseif {$toolbar == [_ "Copy/Transform"]} {
	return [list {gid55.html#UTILITIES>Copy}]
    } elseif {$toolbar == [_ "Layers"]} {
	return [list {gid53.html#UTILITIES>Layers}]
    } elseif {$toolbar == [_ "Preferences"]} {
	return [list {gid52.html#UTILITIES>Preferences}]
    } elseif {$toolbar == [_ "Help"]} {
	return [list {gid110.html#HELP}]
    } elseif {$toolbar == [_ "Exit GiD"]} {
	return [list {gid25.html#FILES>Quit}]
    } elseif {$toolbar == [_ "Zoom in"] \
	    || $toolbar == [_ "Zoom out"] \
	    || $toolbar == [_ "Zoom frame"]} {
	return [list {gid27.html#VIEW>Zoom}]
    } elseif {$toolbar == [_ "Redraw"]} {
	return [list {gid30.html#VIEW>Redraw}]
    } elseif {$toolbar == [_ "Rotate trackball"]} {
	return [list {gid28.html#VIEW>Rotate>Rotate trackbal}]
    } elseif {$toolbar == [_ "Pan dynamic"]} {
	return [list {gid29.html#VIEW>Pan}]
    } elseif {$toolbar == [_ "Create line"]} {
	return [list  {gid47.html#GEOMETRY>Create>Straight line creation}]
    } elseif {$toolbar == [_ "Create arc"]} {
	return [list {gid47.html#GEOMETRY>Create>Arc creation}]
    } elseif {$toolbar == [_ "Create nurbs line"]} {
	return [list {gid47.html#GEOMETRY>Create>NURBS line creation}]
    } elseif {$toolbar == [_ "Create polyline"]} {
	return [list {gid47.html#GEOMETRY>Create>Polyline creation}]
    } elseif {$toolbar == [_ "Create NURBS surface"]} {
	return [list {gid47.html#GEOMETRY>Create>NURBS surface creation}]
    } elseif {$toolbar == [_ "Create volume"]} {
	return [list {gid47.html#GEOMETRY>Create>Volume creation}]
    } elseif {$toolbar == [_ "Create Object:\n  Rectangle\n Polygon\n  Circle\n  Sphere\n  Cylinder\n  Cone\n  Prism\n Thorus"]} {
	return [list {gid47.html#GEOMETRY>Create>Object}]
    } elseif {$toolbar == [_ "Delete"]} {
	return [list {gid48.html#GEOMETRY>Delete}]
    } elseif {$toolbar == [_ "List entities"] } {
	set viewmode [GiD_Info project ViewMode]
	if { $viewmode == "GEOMETRYUSE" || $viewmode == "MESHUSE" } {
	    return [list {gid58.html#UTILITIES>List}]
	} else {
	    return [list {gid113.html#POSTPROCESS OPTIONS>Utilities menu}]
	}
    } elseif {$toolbar == [_ "Toggle geometry-mesh view"]} {
	return [list {gid44.html#VIEW>Mode}]
    } elseif {$toolbar == [_ "Change light vector direction"] } {
	return [list {gid31.html#VIEW>Render}]
    } elseif {$toolbar == [_ "Display Style"] \
	    || $toolbar == [_ "View style"] \
	    || $toolbar == [_ "Culling Style"] \
	    || $toolbar == [_ "Switch Volume sets On/Off"] \
	    || $toolbar == [_ "Switch Surface set On/Off"] \
	    || $toolbar == [_ "Switch Cut set On/Off"]} {
	return [list {gid116.html#POSTPROCESS OPTIONS>Display Style}]
    } elseif {$toolbar == [_ "Cut Volume/Surface sets with 2/3 points, succesion#C#menu"]} {
	return [list {gid114.html#POSTPROCESS RESULTS>Do Cuts}]
    } elseif {$toolbar == [_ "Set maximum value"] \
	    || $toolbar == [_ "Set minimum value"] \
	    || $toolbar == [_ "Reset Contour Limit Values"]} {
	return [list {gid124.html#POSTPROCESS RESULTS>Contour Fill}]
    } elseif {$toolbar == [_ "Record macro"] \
	    || $toolbar == [_ "Edit macros..."] } {
	return [list {gid54.html#UTILITIES>Macros}]
    } elseif {$toolbar == [_ "Open a simple editor to save small notes with the model"]} {
	return [list {gid54.html#UTILITIES>Notes}]
    } elseif {$toolbar == [_ "Dimension distance between two points"] \
	    || $toolbar == [_ "Modify the dimension text"]} {
	return [list {gid64.html#UTILITIES>Dimensions}]
    } elseif {$toolbar == [_ "Create a trimmed surface from a base surface and a new boundary"]} {
	return [list {gid47.html#GEOMETRY>Create>NURBS surface creation}]
    } elseif {$toolbar == [_ "Create a hole in a surface from a line's loop "]} {
	return [list {gid49.html#GEOMETRY>Edit>Hole NURBS surface}] 
    } elseif {$toolbar == [_ "Move a point (Warning: surfaces can't support big deformation)"]} {
	return [list {gid49.html#GEOMETRY>Edit>Move point}]
    } elseif {$toolbar == [_ "Divide a line in a number of divisions"]} {
	return [list {gid49.html#GEOMETRY>Edit>Divide}]
    }
    return {}
}

# tutorials ini window#

proc CreateTutorial_win {} {
    global GIDDEFAULT GidPriv
    
    set w .gid.tutorials 
    InitWindow $w [_ "GiD tutorials"] GiDTutorialsWindowGeom CreateTutorial_win "" 1
    if { ![winfo exists $w] } return ;# windows disabled || usemorewindows == 0
    $w configure -background #EEEEEE
    #wm minsize $w 430 430
    #wm maxsize $w 430 430
    set dir [file join [GiDGetInfoDir] html-tutorials images_1]
    set image_tutorials [image create photo -file [file join $dir gidtutorials.gif]]       
    set image_tutorial1 [image create photo -file [file join $dir tutorial1.gif]]       
    set image_tutorial2 [image create photo -file [file join $dir tutorial2.gif]]       
    set image_tutorial3 [image create photo -file [file join $dir tutorial3.gif]]       
    
    set image_tutorial1_over [image create photo -file [file join $dir tutorial1_o.gif]]       
    set image_tutorial2_over [image create photo -file [file join $dir tutorial2_o.gif]]       
    set image_tutorial3_over [image create photo -file [file join $dir tutorial3_o.gif]]       
    
    label $w.label_imgtop -image $image_tutorials -bd 0
    
    button $w.button#1 \
	    -relief flat \
	    -image $image_tutorial1 -background #EEEEEE \
	    -command {
	GiDHelpWindow -type REFERENCE -start [file join html-tutorials]
	destroy .gid.tutorials
    }


    button $w.button#2 \
	    -relief flat \
	    -image $image_tutorial2 -background #EEEEEE \
	    -command {
	GiDHelpWindow -type REFERENCE  -start [file join html-tutorials index2.html] 
	destroy .gid.tutorials
    }

    button $w.button#3 \
	    -relief flat \
	    -image $image_tutorial3 -background #EEEEEE \
	    -command {
	GiDHelpWindow -type REFERENCE -start [file join html-tutorials index3.html] 
	destroy .gid.tutorials
    }
  
    bind $w.button#1 <Enter> ".gid.tutorials.button#1 configure -image $image_tutorial1_over"
    bind $w.button#1 <Leave> ".gid.tutorials.button#1 configure -image $image_tutorial1"
    
    bind $w.button#2 <Enter> ".gid.tutorials.button#2 configure -image $image_tutorial2_over"
    bind $w.button#2 <Leave> ".gid.tutorials.button#2 configure -image $image_tutorial2"
    
    bind $w.button#3 <Enter> ".gid.tutorials.button#3 configure -image $image_tutorial3_over"
    bind $w.button#3 <Leave> ".gid.tutorials.button#3 configure -image $image_tutorial3"
  
  
    # Geometry management
    
    grid $w.label_imgtop -in $w        -row 0 -column 0 -columnspan 2 -sticky ne
    grid $w.button#1 -in $w        -row 1 -column 0 
    grid $w.button#2 -in $w        -row 1 -column 1 
    grid $w.button#3 -in $w        -row 2 -column 0 -columnspan 2
    
    
    # Resize behavior management
    
    grid rowconfigure $w 1 -weight 1 -minsize 30
    #grid rowconfigure $w 2 -weight 0 -minsize 174
    #grid columnconfigure $w 1 -weight 0 -minsize 199
    #grid columnconfigure $w 2 -weight 0 -minsize 253
    
    #grid rowconfigure $w.frame 1 -weight 0 -minsize 30
    #grid columnconfigure $w.frame 1 -weight 0 -minsize 30
    
    if { $::tcl_platform(os) != "Darwin"} {
	tkwait visibility $w
    } else {
	update
    }

    grab $w 
}

proc CreateGiDInfo_win {} {
    global GIDDEFAULT GidPriv tcl_platform
    
    set w .gid.info_gid
    InitWindow $w [_ "GiD Info"] GiDInfoWindowGeom CreateGiDInfo_win "" 1
    if { ![winfo exists $w] } return ;# windows disabled || usemorewindows == 0
    $w configure -background #EEEEEE
    #wm minsize $w 459 330
    #wm maxsize $w 459 330
    set image_top  [image create photo -file [file join $GIDDEFAULT bitmaps gidinfo.gif]]       
    set image_but1 [image create photo -file [file join $GIDDEFAULT bitmaps buton_about.gif]]       
    set image_but2 [image create photo -file [file join $GIDDEFAULT bitmaps buton_help.gif]]       
    set image_but3 [image create photo -file [file join $GIDDEFAULT bitmaps buton_tutorials.gif]]       
    set image_but4 [image create photo -file [file join $GIDDEFAULT bitmaps buton_web.gif]]       
    set image_but5 [image create photo -file [file join $GIDDEFAULT bitmaps buton_register.gif]]       
    set image_but6 [image create photo -file [file join $GIDDEFAULT bitmaps buton_close.gif]]       
    
    set image_but1_over [image create photo -file [file join $GIDDEFAULT bitmaps buton_about_o.gif]]       
    set image_but2_over [image create photo -file [file join $GIDDEFAULT bitmaps buton_help_o.gif]]       
    set image_but3_over [image create photo -file [file join $GIDDEFAULT bitmaps buton_tutorials_o.gif]]       
    set image_but4_over [image create photo -file [file join $GIDDEFAULT bitmaps buton_web_o.gif]]       
    set image_but5_over [image create photo -file [file join $GIDDEFAULT bitmaps buton_register_o.gif]]       
    set image_but6_over [image create photo -file [file join $GIDDEFAULT bitmaps buton_close_o.gif]]       
    
    
    set image_txt1 [image create photo -file [file join $GIDDEFAULT bitmaps text_about.gif]]       
    set image_txt2 [image create photo -file [file join $GIDDEFAULT bitmaps text_gidhelp.gif]]       
    set image_txt3 [image create photo -file [file join $GIDDEFAULT bitmaps text_gidtutorials.gif]]       
    set image_txt4 [image create photo -file [file join $GIDDEFAULT bitmaps text_www.gif]]       
    set image_txt5 [image create photo -file [file join $GIDDEFAULT bitmaps text_register.gif]] 
    set image_txt6 [image create photo -file [file join $GIDDEFAULT bitmaps text_close.gif]] 
    #set image_txt7 [image create photo -file [file join $GIDDEFAULT bitmaps text_customization.gif]] 
    #set image_txt8 [image create photo -file [file join $GIDDEFAULT bitmaps text_whatsnew.gif]] 
    #set image_txt9 [image create photo -file [file join $GIDDEFAULT bitmaps text_faq.gif]] 
    
    label $w.label_imgtop -image $image_top -bd 0
    
    label $w.label_about                -image $image_txt1 -bd 0  -bg #EEEEEE
    label $w.label_help                -image $image_txt2 -bd 0  -bg #EEEEEE
    label $w.label_tutorials        -image $image_txt3 -bd 0  -bg #EEEEEE
    label $w.label_web                -image $image_txt4 -bd 0  -bg #EEEEEE
    label $w.label_register        -image $image_txt5 -bd 0  -bg #EEEEEE
    label $w.label_close         -image $image_txt6 -bd 0  -bg #EEEEEE
    
    
    
    button $w.button#1 \
	    -relief flat -bd 0 -bg #EEEEEE -highlightthickness 0\
	    -image $image_but1  \
	    -command {CreateWelcomeWin }
    
    
    menubutton $w.button#2 \
	    -relief flat -bd 0 -bg #EEEEEE -highlightthickness 0 \
	    -image $image_but2  \
	    -menu $w.button#2.m -relief flat -bd 0 
    
    
    menu $w.button#2.m -tearoff no -bd 1  -bg $GidPriv(Color,ToolbarBg)
    $w.button#2.m add command -label [_ "GiD Help"] \
	    -command {GiDHelpWindow -type REFERENCE -start html-version}
    $w.button#2.m add command  -label [_ "Customization Help"] \
	    -command {GiDHelpWindow -type REFERENCE -start html-customization}
    $w.button#2.m add command -label [_ "FAQ"]  \
	    -command {GiDHelpWindow -type REFERENCE -start html-faq}
    $w.button#2.m add command  -label [_ "What's new"]...  \
	    -command {GiDHelpWindow -type REFERENCE -start html_whatsnew}
    
    button $w.button#3 \
	    -relief flat -bd 0 -bg #EEEEEE -highlightthickness 0 \
	    -image $image_but3 \
	    -command {
	CreateTutorial_win 
	destroy .gid.info_gid
    }
    
    button $w.button#4 \
	    -relief flat -bd 0 -bg #EEEEEE -highlightthickness 0 \
	    -image $image_but4  \
	    -command "VisitWeb $GidPriv(ProgWeb)"
    
    
    menubutton $w.button#5 \
	    -relief flat -bd 0 -bg #EEEEEE -highlightthickness 0 \
	    -image $image_but5  \
	    -menu $w.button#5.m -relief flat -bd 0
    
    menu $w.button#5.m -tearoff no -bd 1  -bg $GidPriv(Color,ToolbarBg)
    $w.button#5.m add command -label [_ "Register GiD"] \
	    -command {gidregister}
    $w.button#5.m add command  -label [_ "Register Problem type"] \
	    -command {gidregister module}
    
    
    button $w.button#6 \
	    -relief flat -bd 0 -bg #EEEEEE -highlightthickness 0 \
	    -image $image_but6  \
	    -command {destroy .gid.info_gid }
    
    #binds - on mouse over 
    
    bind $w.button#1 <Enter> ".gid.info_gid.button#1 configure -image $image_but1_over"
    bind $w.button#1 <Leave> ".gid.info_gid.button#1 configure -image $image_but1 "
    
    bind $w.button#2 <Enter> ".gid.info_gid.button#2 configure -image $image_but2_over"
    bind $w.button#2 <Leave> ".gid.info_gid.button#2 configure -image $image_but2 "
    
    bind $w.button#3 <Enter> ".gid.info_gid.button#3 configure -image $image_but3_over"
    bind $w.button#3 <Leave> ".gid.info_gid.button#3 configure -image $image_but3 "
    
    bind $w.button#4 <Enter> ".gid.info_gid.button#4 configure -image $image_but4_over"
    bind $w.button#4 <Leave> ".gid.info_gid.button#4 configure -image $image_but4 "
    
    bind $w.button#5 <Enter> ".gid.info_gid.button#5 configure -image $image_but5_over"
    bind $w.button#5 <Leave> ".gid.info_gid.button#5 configure -image $image_but5 "
    
    bind $w.button#6 <Enter> ".gid.info_gid.button#6 configure -image $image_but6_over"
    bind $w.button#6 <Leave> ".gid.info_gid.button#6 configure -image $image_but6 "
    
    # Geometry management
    
    grid $w.label_imgtop -in $w        -row 1 -column 1  \
	    -columnspan 6 -sticky ne
    grid $w.button#1        -in $w        -row 2 -column 2  
    grid $w.label_about        -in $w        -row 2 -column 3 
    grid $w.button#3        -in $w        -row 2 -column 4 -ipady 5
    grid $w.label_tutorials  -in $w        -row 2 -column 5 
    
    grid $w.button#2        -in $w        -row 3 -column 2 -ipady 5 
    grid $w.label_help        -in $w        -row 3 -column 3 
    
    grid $w.button#5        -in $w        -row 3 -column 4 -ipady 5 
    grid $w.label_register        -in $w        -row 3 -column 5  
    grid $w.button#4        -in $w        -row 4 -column 2 -ipady 5
    grid $w.label_web        -in $w        -row 4 -column 3 
    grid $w.button#6        -in $w        -row 4 -column 4 -ipady 5
    grid $w.label_close        -in $w        -row 4 -column 5
   
    
    # Resize behavior management
    
    grid rowconfigure $w 1 -weight 1 
    #grid rowconfigure $w 2 -weight 0 -minsize 2
    grid rowconfigure $w 5 -weight 0 -minsize 10
    
    grid columnconfigure $w 1 -weight 0 -minsize 15
    grid columnconfigure $w 2 -weight 0 -minsize 30
    grid columnconfigure $w 3 -weight 0 -minsize 30
    grid columnconfigure $w 4 -weight 0 -minsize 30
    grid columnconfigure $w 5 -weight 0 -minsize 40
    grid columnconfigure $w 6 -weight 0 -minsize 10
}


# whatisnewViwer is not used any more. see function HelpWindow "CUSTOM_HELP_FILE" #
proc WhatIsNewViewer { { name  "" } } {
    global GIDDEFAULT

    if { $name == "" } {
	set name $GIDDEFAULT/info/WHATISNEW
    }

    set w .gid.__fileviewer
    InitWindow $w [_ "What is new"] WhatIsNewWindowGeom WhatIsNewViewe
    if { ![winfo exists $w] } return ;# windows disabled || usemorewindows == 0

    $w config -bg grey93

    set imatge_quit [image create photo -file [file join $GIDDEFAULT bitmaps quit.gif]] 




    text $w.t -relief raised -bd 2 -xscrollcommand "$w.sx set" \
	    -yscrollcommand "$w.sy set"
    scrollbar $w.sy -relief flat -command "$w.t yview"
    scrollbar $w.sx -relief flat -command "$w.t xview" -orient h
    button $w.b -text [_ "Close"] -command "destroy $w" -image $imatge_quit -background grey93 -relief flat
    SetWidgetsWidthFromText w.b

    grid $w.t -row 1 -column 1 -sticky nsew
    grid $w.sy -row 1 -column 2 -sticky ns
    #grid $w.sx -row 2 -column 1 -sticky ew
    grid $w.b -row 3 -column 1 -columnspan 2 -pady 7 -sticky e

    grid columnconf $w 1 -weight 1
    grid rowconf $w 1 -weight 1

    set f [open $name r]
    while { ![eof $f] } {
	$w.t ins end [gets $f]\n
    }
    close $f
    focus $w.t
    $w.t conf -state disabled
}


proc VisitWeb { dir } { 
    global tcl_platform
  
    if { $tcl_platform(platform) == "windows" } { 
	catch {eval exec [auto_execok start] $dir >& NUL: &}
    } elseif { $::tcl_platform(os) == "Darwin"} {
	set err ""
	catch { exec open "$dir"} err
	if { $err != ""} {
	    WarnWin $err
	}
    } else {
	#catch {exec netscape $dir >& /dev/null &} 
	set err1 ""
	set err2 ""
	set err3 ""
	set err4 ""
	if { [ catch {exec firefox $dir &} err1]} {
	    if { [ catch {exec mozilla $dir &} err2]} {
		if { [ catch {exec opera $dir &} err3]} {
		    catch {exec konqueror $dir &} err4
		}
	    }
	} 
	if { ( $err1 != "") || ( $err2 != "") || ( $err3 != "") || ( $err4 != "")} {
	    WarnWin "$err1\n$err2\n$err3\n$err4"
	}
    }
}

